@@ -962,8 +962,12 @@ class SGrid(object):
         elif location in edge1_alternate_names:
             #interpolate as a uniform gradient from 'left side' to 'right side'
             center_idxs = self.apply_padding_to_idxs(ind.copy(), padding=self.get_padding_by_location('center'))
-            cm = gen_celltree_mask_from_center_mask(self.center_mask, np.s_[:])
-            cm = np.ma.MaskedArray(cm, mask=False)\
+            if self.center_mask is None:
+                cm = np.zeros((self.node_lon.shape[0] - 1, self.node_lon.shape[1] - 1)).astype(np.bool)
+                cm = np.ma.MaskedArray(cm, mask=False)
+            else:
+                cm = gen_celltree_mask_from_center_mask(self.center_mask, np.s_[:])
+                cm = np.ma.MaskedArray(cm, mask=False)
 
             u2_offset = [0, 1]
             alpha_dim_idx = 0
@@ -983,8 +987,12 @@ class SGrid(object):
         elif location in edge2_alternate_names:
             #interpolate as a uniform gradient from 'bottom' to 'top'
             center_idxs = self.apply_padding_to_idxs(ind.copy(), padding=self.get_padding_by_location('center'))
-            cm = gen_celltree_mask_from_center_mask(self.center_mask, np.s_[:])
-            cm = np.ma.MaskedArray(cm, mask=False)
+            if self.center_mask is None:
+                cm = np.zeros((self.node_lon.shape[0] - 1, self.node_lon.shape[1] - 1)).astype(np.bool)
+                cm = np.ma.MaskedArray(cm, mask=False)
+            else:
+                cm = gen_celltree_mask_from_center_mask(self.center_mask, np.s_[:])
+                cm = np.ma.MaskedArray(cm, mask=False)
             
             v2_offset = [1, 0]
             alpha_dim_idx = 1
